@@ -2,7 +2,7 @@ from django.contrib import admin
 
 # Register your models here.
 from mptt.admin import DraggableMPTTAdmin
-from djgentelella.models import MenuItem, Help, GentelellaSettings, Notification
+from djgentelella.models import MenuItem, Help, GentelellaSettings, Notification, ChunkedUpload
 from djgentelella.utils import clean_cache
 from djgentelella.models import PermissionsCategoryManagement
 
@@ -27,6 +27,16 @@ class NotificationAdmin(admin.ModelAdmin):
     list_display = ['description', 'state', 'message_type']
     list_editable = ['state']
 
+
+
+class ChunkedUploadAdmin(admin.ModelAdmin):
+    list_display = ('upload_id', 'filename', 'status', 'created_on')
+    search_fields = ('filename', 'filename')
+    list_filter = ('status',)
+
+
+
+admin.site.register(ChunkedUpload, ChunkedUploadAdmin)
 admin.site.register(MenuItem, MenuAdmin)
 admin.site.register(Help)
 admin.site.register(PermissionsCategoryManagement)
