@@ -63,10 +63,20 @@ document.gtwidgets = {
         instance.daterangepicker(load_datetime_range(instance));
     },
     DateTimeInput: function (instance) {
-        instance.datetimepicker({format : instance.data('format') });// "YYYY-MM-DD HH:mm"
+        instance.datetimepicker({format : instance.data('format'),
+              sideBySide: true, icons: {
+                  time: "fa fa-clock-o",
+                  up: "fa fa-arrow-up",
+                  down: "fa fa-arrow-down"
+              } });// "YYYY-MM-DD HH:mm"
     },
     TimeInput: function (instance) {
-        instance.datetimepicker({format: instance.data('format') }); // 'HH:mm'
+         instance.datetimepicker({format : instance.data('format'),
+              sideBySide: true, icons: {
+                  time: "fa fa-clock-o",
+                  up: "fa fa-arrow-up",
+                  down: "fa fa-arrow-down"
+              } }); // 'HH:mm'
     },
     DateInput: function (instance) {
         instance.datetimepicker({format: instance.data('format')  }); //"DD/MM/YYYY"
@@ -201,7 +211,7 @@ document.gtwidgets = {
                 input.setAttribute('accept', 'image/*');
                 input.onchange = function () {
                     var file = this.files[0];
-                    upload_files(callback, meta, file, instance.attr('data-option-image'), 
+                    upload_files(callback, meta, file, instance.attr('data-option-image'),
                     instance.attr('data-option-video'));
                 };
                 input.click();
@@ -223,24 +233,28 @@ document.gtwidgets = {
     DJGraph: function (instance) {
         instance.gentelella_chart();
     },
+    NullBooleanSelect: function(instance){
+	    instance.iCheck({
+            checkboxClass: 'icheckbox_flat-green',
+            radioClass: 'iradio_flat-green'
+        });
+     },
     UrlTimeLineInput: function (instance) {
-        var instanceid = instance.attr('id');
-        var dataoptions = $(id_timeline).data();
-        var keys = Object.keys(dataoptions);
-        var options = {}
-        for (var x=0; x<keys.length; x++){
-            if(keys[x].startsWith('option_')){
-                 options[keys[x].replace('option_', '')] = dataoptions[keys[x]]
-            }
-        }
-        var timeline = new TL.Timeline(instanceid, instance.data('url'), options);
-        window.addEventListener('resize', function() {
-            var embed = document.getElementById(instanceid);
-            embed.style.height = getComputedStyle(document.body).height;
-            timeline.updateDisplay();
-        })
-    }
+        build_timeline(instance);
+    },
 
+    CalendarInput: function (instance) {
+        build_calendar(instance);
+    },
+    GigaPixelStoryMapInput: function (instance) {
+        build_gigapixel_storymap(instance);
+    },
+    MapBasedStoryMapInput: function (instance) {
+        build_mapbased_storymap(instance);
+    },
+    UrlStoryLineInput: function (instance) {
+        build_storyline(instance)
+    }
 }
 
 function gt_find_initialize(instance) {
@@ -255,12 +269,11 @@ function gt_find_initialize(instance) {
     if (autocomplete.length > 0) {
         document.gtwidgets['GTAutocompleteSelect'](autocomplete);
     }
-
-
 }
 
 $(document).ready(function () {
     $(".formset").each(function (index, elem) {
         document.formset.push(gtformSetManager($(elem)));
     });
+
 });
\ No newline at end of file
