@@ -21,6 +21,7 @@ def validate_menu_item(item, context):
         return item
 
 
+
 def render_item(item, env={}, widget_list=[], ariabylabel=''):
     item = validate_menu_item(item, env)
     if not item:
@@ -31,17 +32,19 @@ def render_item(item, env={}, widget_list=[], ariabylabel=''):
     a_class=""
     icon=""
     if item.level > 0:
+
         dropdown = "dropdown-submenu pull-left"
         if not children:
-            dropdown =  ""
-    dev = '<li id="i_%d" role="presentation" class="%s imenu%d" >'%(item.pk, dropdown, item.pk)
+            dropdown = ""
+    dev = '<li id="i_%d" role="presentation" class="%s imenu%d"  >'%(item.pk, dropdown, item.pk)
 
     if item.icon:
         icon = format_html('<i class="{}"></i>', item.icon)
     if children and item.level == 0:
-        a_class = 'class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false"'
+        a_class = 'class="dropdown-toggle" data-bs-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false"'
     else:
         a_class = 'tabindex = "-1"'
+
     if item.is_widget:
         wdcontext = {'id': 'tm_'+str(item.id), 'item': item}
         wdcontext.update(env)
@@ -63,6 +66,7 @@ def render_item(item, env={}, widget_list=[], ariabylabel=''):
     if children:
         dev += '</ul>'
     dev += '</li>'
+
     return dev
 
 register = template.Library()
